You are viewing a plain text version of this content. The canonical link for it is here.
Posted to java-dev@axis.apache.org by ch...@apache.org on 2006/02/01 10:05:11 UTC

svn commit: r374025 [8/8] - in /webservices/axis2/trunk/java: etc/ modules/adb/src/org/apache/axis2/databinding/ modules/adb/src/org/apache/axis2/databinding/deserializers/ modules/adb/test/org/apache/axis2/databinding/ modules/codegen/src/org/apache/a...

Modified: webservices/axis2/trunk/java/modules/saaj/src/org/apache/axis2/saaj/TextImplEx.java
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/java/modules/saaj/src/org/apache/axis2/saaj/TextImplEx.java?rev=374025&r1=374024&r2=374025&view=diff
==============================================================================
--- webservices/axis2/trunk/java/modules/saaj/src/org/apache/axis2/saaj/TextImplEx.java (original)
+++ webservices/axis2/trunk/java/modules/saaj/src/org/apache/axis2/saaj/TextImplEx.java Wed Feb  1 00:58:23 2006
@@ -15,11 +15,11 @@
  */
 package org.apache.axis2.saaj;
 
-import org.apache.axis.om.DOOMAbstractFactory;
+import org.apache.axis2.om.DOOMAbstractFactory;
 import org.apache.ws.commons.om.OMContainer;
 import org.apache.ws.commons.om.OMException;
 import org.apache.ws.commons.om.impl.OMOutputImpl;
-import org.apache.axis2.doom.dom.TextImpl;
+import org.apache.axis2.om.impl.dom.TextImpl;
 import org.w3c.dom.DOMException;
 
 import javax.xml.soap.Text;

Modified: webservices/axis2/trunk/java/modules/saaj/src/org/apache/axis2/saaj/util/SAAJUtil.java
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/java/modules/saaj/src/org/apache/axis2/saaj/util/SAAJUtil.java?rev=374025&r1=374024&r2=374025&view=diff
==============================================================================
--- webservices/axis2/trunk/java/modules/saaj/test/org/apache/axis2/saaj/AttachmentSerializationTest.java (original)
+++ webservices/axis2/trunk/java/modules/saaj/test/org/apache/axis2/saaj/AttachmentSerializationTest.java Wed Feb  1 00:58:23 2006
@@ -71,7 +71,7 @@
         msg.addAttachmentPart(ap);
 
         // Second attachment
-        String jpgfilename = "test-resources/axis.jpg";
+        String jpgfilename = "test-resources/axis2.jpg";
         File myfile = new File(jpgfilename);
         FileDataSource fds = new FileDataSource(myfile);
         DataHandler dh = new DataHandler(fds);

Modified: webservices/axis2/trunk/java/modules/saaj/test/org/apache/axis2/saaj/SOAPElementTest.java
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/java/modules/saaj/test/org/apache/axis2/saaj/SOAPElementTest.java?rev=374025&r1=374024&r2=374025&view=diff
==============================================================================
--- webservices/axis2/trunk/java/modules/saaj/test/org/apache/axis2/saaj/SOAPElementTest.java (original)
+++ webservices/axis2/trunk/java/modules/saaj/test/org/apache/axis2/saaj/SOAPElementTest.java Wed Feb  1 00:58:23 2006
@@ -16,7 +16,7 @@
 package org.apache.axis2.saaj;
 
 import junit.framework.TestCase;
-import org.apache.axis2.doom.dom.NodeImpl;
+import org.apache.axis2.om.impl.dom.NodeImpl;
 
 import javax.xml.soap.SOAPElement;
 import java.util.List;

Modified: webservices/axis2/trunk/java/modules/saaj/test/org/apache/axis2/saaj/SOAPFaultDetailTest.java
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/java/modules/saaj/test/org/apache/axis2/saaj/SOAPFaultDetailTest.java?rev=374025&r1=374024&r2=374025&view=diff
==============================================================================
--- webservices/axis2/trunk/java/modules/saaj/test/org/apache/axis2/saaj/SOAPFaultDetailTest.java (original)
+++ webservices/axis2/trunk/java/modules/saaj/test/org/apache/axis2/saaj/SOAPFaultDetailTest.java Wed Feb  1 00:58:23 2006
@@ -26,7 +26,7 @@
     	"   <faultstring></faultstring>" +
     	"   <detail>" +
     	"    <tickerSymbol xsi:type=\"xsd:string\">MACR</tickerSymbol>" +
-    	"   <ns1:exceptionName xmlns:ns1=\"http://xml.apache.org/axis/\">test.wsdl.faults.InvalidTickerFaultMessage</ns1:exceptionName>" +
+    	"   <ns1:exceptionName xmlns:ns1=\"http://xml.apache.org/axis2/\">test.wsdl.faults.InvalidTickerFaultMessage</ns1:exceptionName>" +
     	"   </detail>" +
     	"  </soapenv:Fault>" +
     	" </soapenv:Body>" +

Modified: webservices/axis2/trunk/java/modules/saaj/test/org/apache/axis2/saaj/integration/IntegrationTest.java
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/java/modules/saaj/test/org/apache/axis2/saaj/integration/IntegrationTest.java?rev=374025&r1=374024&r2=374025&view=diff
==============================================================================
--- webservices/axis2/trunk/java/modules/saaj/test/org/apache/axis2/saaj/integration/IntegrationTest.java (original)
+++ webservices/axis2/trunk/java/modules/saaj/test/org/apache/axis2/saaj/integration/IntegrationTest.java Wed Feb  1 00:58:23 2006
@@ -110,7 +110,7 @@
         request.addAttachmentPart(textAttach);
 
         //Attach a java.awt.Image object to the SOAP request
-        String jpgfilename = "test-resources/axis.jpg";
+        String jpgfilename = "test-resources/axis2.jpg";
         File myfile = new File(jpgfilename);
         FileDataSource fds = new FileDataSource(myfile);
         DataHandler imageDH = new DataHandler(fds);

Modified: webservices/axis2/trunk/java/modules/security/interop/org/apache/axis2/security/InteropScenarioClient.java
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/java/modules/security/interop/org/apache/axis2/security/InteropScenarioClient.java?rev=374025&r1=374024&r2=374025&view=diff
==============================================================================
--- webservices/axis2/trunk/java/modules/security/interop/org/apache/axis2/security/InteropScenarioClient.java (original)
+++ webservices/axis2/trunk/java/modules/security/interop/org/apache/axis2/security/InteropScenarioClient.java Wed Feb  1 00:58:23 2006
@@ -22,8 +22,8 @@
 import org.apache.axis2.security.handler.WSSHandlerConstants;
 import org.apache.axis2.security.handler.config.InflowConfiguration;
 import org.apache.axis2.security.handler.config.OutflowConfiguration;
-import org.apache.axis2.soap.SOAP11Constants;
-import org.apache.axis2.soap.SOAP12Constants;
+import org.apache.ws.commons.soap.SOAP11Constants;
+import org.apache.ws.commons.soap.SOAP12Constants;
 import org.xmlsoap.ping.*;
 
 /**

Modified: webservices/axis2/trunk/java/modules/security/src/org/apache/axis2/security/WSDoAllReceiver.java
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/java/modules/security/src/org/apache/axis2/security/WSDoAllReceiver.java?rev=374025&r1=374024&r2=374025&view=diff
==============================================================================
--- webservices/axis2/trunk/java/modules/security/src/org/apache/axis2/security/WSDoAllReceiver.java (original)
+++ webservices/axis2/trunk/java/modules/security/src/org/apache/axis2/security/WSDoAllReceiver.java Wed Feb  1 00:58:23 2006
@@ -20,8 +20,8 @@
 import org.apache.axis2.context.MessageContext;
 import org.apache.axis2.context.OperationContext;
 import org.apache.ws.commons.om.OMException;
-import org.apache.axis2.doom.dom.DocumentImpl;
-import org.apache.axis2.doom.dom.jaxp.DocumentBuilderFactoryImpl;
+import org.apache.axis2.om.impl.dom.DocumentImpl;
+import org.apache.axis2.om.impl.dom.jaxp.DocumentBuilderFactoryImpl;
 import org.apache.axis2.security.handler.WSDoAllHandler;
 import org.apache.axis2.security.handler.WSSHandlerConstants;
 import org.apache.axis2.security.util.Axis2Util;

Modified: webservices/axis2/trunk/java/modules/security/src/org/apache/axis2/security/WSDoAllSender.java
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/java/modules/security/src/org/apache/axis2/security/WSDoAllSender.java?rev=374025&r1=374024&r2=374025&view=diff
==============================================================================
--- webservices/axis2/trunk/java/modules/security/src/org/apache/axis2/security/WSDoAllSender.java (original)
+++ webservices/axis2/trunk/java/modules/security/src/org/apache/axis2/security/WSDoAllSender.java Wed Feb  1 00:58:23 2006
@@ -19,8 +19,8 @@
 import org.apache.axis2.AxisFault;
 import org.apache.axis2.context.MessageContext;
 import org.apache.axis2.context.OperationContext;
-import org.apache.axis2.doom.dom.DocumentImpl;
-import org.apache.axis2.doom.dom.jaxp.DocumentBuilderFactoryImpl;
+import org.apache.axis2.om.impl.dom.DocumentImpl;
+import org.apache.axis2.om.impl.dom.jaxp.DocumentBuilderFactoryImpl;
 import org.apache.axis2.security.handler.WSDoAllHandler;
 import org.apache.axis2.security.handler.WSSHandlerConstants;
 import org.apache.axis2.security.util.Axis2Util;

Modified: webservices/axis2/trunk/java/modules/security/src/org/apache/axis2/security/util/Axis2Util.java
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/java/modules/security/src/org/apache/axis2/security/util/Axis2Util.java?rev=374025&r1=374024&r2=374025&view=diff
==============================================================================
--- webservices/axis2/trunk/java/modules/security/src/org/apache/axis2/security/util/Axis2Util.java (original)
+++ webservices/axis2/trunk/java/modules/security/src/org/apache/axis2/security/util/Axis2Util.java Wed Feb  1 00:58:23 2006
@@ -23,9 +23,9 @@
 import javax.xml.stream.XMLInputFactory;
 import javax.xml.stream.XMLStreamReader;
 
-import org.apache.axis.om.DOOMAbstractFactory;
+import org.apache.axis2.om.DOOMAbstractFactory;
 import org.apache.ws.commons.om.OMElement;
-import org.apache.axis2.doom.dom.DocumentImpl;
+import org.apache.axis2.om.impl.dom.DocumentImpl;
 import org.apache.ws.commons.om.impl.llom.builder.StAXOMBuilder;
 import org.apache.axis2.security.handler.WSSHandlerConstants;
 import org.apache.ws.commons.soap.SOAP11Constants;

Modified: webservices/axis2/trunk/java/modules/webapp/HappyAxis.jsp
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/java/modules/webapp/HappyAxis.jsp?rev=374025&r1=374024&r2=374025&view=diff
==============================================================================
--- webservices/axis2/trunk/java/modules/webapp/HappyAxis.jsp (original)
+++ webservices/axis2/trunk/java/modules/webapp/HappyAxis.jsp Wed Feb  1 00:58:23 2006
@@ -55,7 +55,7 @@
 %>
 <%!
     /*
-    * Happiness tests for axis. These look at the classpath and warn if things
+    * Happiness tests for axis2. These look at the classpath and warn if things
     * are missing. Normally addng this much code in a JSP page is mad
     * but here we want to validate JSP compilation too, and have a drop-in
     * page for easy re-use
@@ -379,7 +379,7 @@
             "axis2-0.93.jar",
             "Apache-Axis",
             "Axis2 will not work",
-            "http://xml.apache.org/axis/");
+            "http://xml.apache.org/axis2/");
     needed += needClass(out, "org.apache.commons.logging.Log",
             "commons-logging.jar",
             "Jakarta-Commons Logging",
@@ -419,13 +419,13 @@
     //is everythng we need here
     if (needed == 0) {
         //yes, be happy
-        out.write("<i>The core axis libraries are present. </i>");
+        out.write("<i>The core axis2 libraries are present. </i>");
     } else {
         //no, be very unhappy
         response.setStatus(HttpServletResponse.SC_INTERNAL_SERVER_ERROR);
         out.write("<i>"
                 + needed
-                + " core axis librar"
+                + " core axis2 librar"
                 + (needed == 1 ? "y is" : "ies are")
                 + " missing</i>");
     }

Modified: webservices/axis2/trunk/java/modules/webapp/happy_axis.jsp
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/java/modules/webapp/happy_axis.jsp?rev=374025&r1=374024&r2=374025&view=diff
==============================================================================
--- webservices/axis2/trunk/java/modules/webapp/happy_axis.jsp (original)
+++ webservices/axis2/trunk/java/modules/webapp/happy_axis.jsp Wed Feb  1 00:58:23 2006
@@ -45,7 +45,7 @@
 %>
 <%!
     /*
-    * Happiness tests for axis. These look at the classpath and warn if things
+    * Happiness tests for axis2. These look at the classpath and warn if things
     * are missing. Normally addng this much code in a JSP page is mad
     * but here we want to validate JSP compilation too, and have a drop-in
     * page for easy re-use
@@ -363,7 +363,7 @@
             "axis2-0.9.jar",
             "Apache-Axis",
             "Axis2 will not work",
-            "http://xml.apache.org/axis/");
+            "http://xml.apache.org/axis2/");
     needed+=needClass(out, "org.apache.commons.logging.Log",
             "commons-logging.jar",
             "Jakarta-Commons Logging",
@@ -403,13 +403,13 @@
     //is everythng we need here
     if(needed==0) {
         //yes, be happy
-        out.write("<i>The core axis libraries are present. </i>");
+        out.write("<i>The core axis2 libraries are present. </i>");
     } else {
         //no, be very unhappy
         response.setStatus(HttpServletResponse.SC_INTERNAL_SERVER_ERROR);
         out.write("<i>"
                 +needed
-                +" core axis librar"
+                +" core axis2 librar"
                 +(needed==1?"y is":"ies are")
                 +" missing</i>");
     }
@@ -508,7 +508,7 @@
 %>
 <%!
     /*
-    * Happiness tests for axis. These look at the classpath and warn if things
+    * Happiness tests for axis2. These look at the classpath and warn if things
     * are missing. Normally addng this much code in a JSP page is mad
     * but here we want to validate JSP compilation too, and have a drop-in
     * page for easy re-use
@@ -826,7 +826,7 @@
             "axis2-0.9.jar",
             "Apache-Axis",
             "Axis2 will not work",
-            "http://xml.apache.org/axis/");
+            "http://xml.apache.org/axis2/");
     needed+=needClass(out, "org.apache.commons.logging.Log",
             "commons-logging.jar",
             "Jakarta-Commons Logging",
@@ -866,13 +866,13 @@
     //is everythng we need here
     if(needed==0) {
         //yes, be happy
-        out.write("<i>The core axis libraries are present. </i>");
+        out.write("<i>The core axis2 libraries are present. </i>");
     } else {
         //no, be very unhappy
         response.setStatus(HttpServletResponse.SC_INTERNAL_SERVER_ERROR);
         out.write("<i>"
                 +needed
-                +" core axis librar"
+                +" core axis2 librar"
                 +(needed==1?"y is":"ies are")
                 +" missing</i>");
     }

Modified: webservices/axis2/trunk/java/xdocs/0_93/OMTutorial.html
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/java/xdocs/0_93/OMTutorial.html?rev=374025&r1=374024&r2=374025&view=diff
==============================================================================
--- webservices/axis2/trunk/java/xdocs/0_93/OMTutorial.html (original)
+++ webservices/axis2/trunk/java/xdocs/0_93/OMTutorial.html Wed Feb  1 00:58:23 2006
@@ -10,7 +10,7 @@
 <table width="100%">
 <tr>
 <td align="left"><h1>Apache Axis2</h1></td>
-<td align="right"><img src="images/axis.jpg"/></td>
+<td align="right"><img src="images/axis2.jpg"/></td>
 </tr>
 </table>
 end of header section -->

Modified: webservices/axis2/trunk/java/xdocs/0_93/userguide.html
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/java/xdocs/0_93/userguide.html?rev=374025&r1=374024&r2=374025&view=diff
==============================================================================
--- webservices/axis2/trunk/java/xdocs/0_93/userguide.html (original)
+++ webservices/axis2/trunk/java/xdocs/0_93/userguide.html Wed Feb  1 00:58:23 2006
@@ -211,7 +211,7 @@
 <p class="command">&gt;start.bat </p>
 <p>For Linux</p>
 <p class="command">$start.sh</p>        
-<p>This will start the simple axis server in the default port (8080). To start the server in a non default port
+<p>This will start the simple axis2 server in the default port (8080). To start the server in a non default port
 the server script can be used. The sever script however needs two parameters, the repository location and the port.</p>
 
 <p>For windows</p>
@@ -221,7 +221,7 @@
 
 <p><b>
 Note - the directory entered as the repository location needs to have a services directory inside. This is
-absolutely required and AXIS will not create it automatically in the case of the simple axis server. 
+absolutely required and AXIS will not create it automatically in the case of the simple axis2 server.
 </b></p> -->
 Samples</h2>
 

Modified: webservices/axis2/trunk/java/xdocs/0_94/OMTutorial.html
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/java/xdocs/0_94/OMTutorial.html?rev=374025&r1=374024&r2=374025&view=diff
==============================================================================
--- webservices/axis2/trunk/java/xdocs/0_94/OMTutorial.html (original)
+++ webservices/axis2/trunk/java/xdocs/0_94/OMTutorial.html Wed Feb  1 00:58:23 2006
@@ -10,7 +10,7 @@
 <table width="100%">
 <tr>
 <td align="left"><h1>Apache Axis2</h1></td>
-<td align="right"><img alt="" src="images/axis.jpg"/></td>
+<td align="right"><img alt="" src="images/axis2.jpg"/></td>
 </tr>
 </table>
 end of header section -->

Modified: webservices/axis2/trunk/java/xdocs/latest/OMTutorial.html
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/java/xdocs/latest/OMTutorial.html?rev=374025&r1=374024&r2=374025&view=diff
==============================================================================
--- webservices/axis2/trunk/java/xdocs/latest/OMTutorial.html (original)
+++ webservices/axis2/trunk/java/xdocs/latest/OMTutorial.html Wed Feb  1 00:58:23 2006
@@ -10,7 +10,7 @@
 <table width="100%">
 <tr>
 <td align="left"><h1>Apache Axis2</h1></td>
-<td align="right"><img src="images/axis.jpg"/></td>
+<td align="right"><img src="images/axis2.jpg"/></td>
 </tr>
 </table>
 end of header section -->
--- webservices/axis2/trunk/java/modules/saaj/src/org/apache/axis2/saaj/util/SAAJUtil.java (original)
+++ webservices/axis2/trunk/java/modules/saaj/src/org/apache/axis2/saaj/util/SAAJUtil.java Wed Feb  1 00:58:23 2006
@@ -16,7 +16,7 @@
 
 package org.apache.axis2.saaj.util;
 
-import org.apache.axis.om.DOOMAbstractFactory;
+import org.apache.axis2.om.DOOMAbstractFactory;
 import org.apache.ws.commons.om.OMElement;
 import org.apache.ws.commons.soap.SOAP11Constants;
 import org.apache.ws.commons.soap.SOAP12Constants;
@@ -67,9 +67,9 @@
      * Create a DOM Document using the org.apache.ws.commons.soap.SOAPEnvelope
      *
      * @param env An org.apache.ws.commons.soap.SOAPEnvelope instance
      * @return the org.apache.axis.soap.impl.dom.SOAPEnvelopeImpl of the given SOAP Envelope
      */
-    public static org.apache.axis.soap.impl.dom.SOAPEnvelopeImpl
+    public static org.apache.axis2.soap.impl.dom.SOAPEnvelopeImpl
              toDOOMSOAPEnvelope(org.apache.ws.commons.soap.SOAPEnvelope env) {
         env.build();
 
@@ -89,7 +89,7 @@
         SOAPEnvelope envelope = (stAXSOAPModelBuilder).getSOAPEnvelope();
         envelope.build();
 
-        return (org.apache.axis.soap.impl.dom.SOAPEnvelopeImpl) envelope;
+        return (org.apache.axis2.soap.impl.dom.SOAPEnvelopeImpl) envelope;
     }
 
     public static org.apache.ws.commons.soap.SOAPEnvelope
@@ -67,9 +67,9 @@
      *
      * @param env An org.apache.ws.commons.soap.SOAPEnvelope instance
-     * @return the org.apache.axis.soap.impl.dom.SOAPEnvelopeImpl of the given SOAP Envelope
+     * @return the org.apache.axis2.soap.impl.dom.SOAPEnvelopeImpl of the given SOAP Envelope
      */

Modified: webservices/axis2/trunk/java/modules/saaj/test/org/apache/axis2/saaj/AttachmentSerializationTest.java
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/java/modules/saaj/test/org/apache/axis2/saaj/AttachmentSerializationTest.java?rev=374025&r1=374024&r2=374025&view=diff
==============================================================================